package com.slibra.web.controller.business;

import java.util.*;
import javax.servlet.http.HttpServletResponse;

import com.slibra.business.res.UserTypeResp;
import com.slibra.common.core.domain.R;
import com.slibra.common.exception.ServiceException;
import com.slibra.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TCallRecord;
import com.slibra.business.service.ITCallRecordService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

import org.springframework.core.io.ByteArrayResource;
import org.springframework.core.io.InputStreamResource;
import org.springframework.core.io.Resource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.io.*;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * 通话记录Controller
 * 
 * @author slibra
 * @date 2024-11-11
 */
@RestController
@RequestMapping("/business/record")
public class TCallRecordController extends BaseController
{
    @Autowired
    private ITCallRecordService tCallRecordService;

    /*@Value("${DOMAIN}")
    private String domain;

    @Value("${URL_DISK_PREFIX}")
    private String urlDiskPrefix;*/

    @Value("${FILE_URL_PREFIX}")
    private String fileUrlPrefix;

    /**
     * 查询通话记录列表
     */
//    @PreAuthorize("@ss.hasPermi('business:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCallRecord tCallRecord)
    {
        startPage();
        List<TCallRecord> list = tCallRecordService.selectTCallRecordList(tCallRecord);
        return getDataTable(list);
    }

    /**
     * 导出通话记录列表
     */
//    @PreAuthorize("@ss.hasPermi('business:record:export')")
//    @Log(title = "通话记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCallRecord tCallRecord)
    {
        List<TCallRecord> list = tCallRecordService.selectTCallRecordList(tCallRecord);
        ExcelUtil<TCallRecord> util = new ExcelUtil<TCallRecord>(TCallRecord.class);
        util.exportExcel(response, list, "通话记录数据");
    }

    /**
     * 获取通话记录详细信息
     */
//    @PreAuthorize("@ss.hasPermi('business:record:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tCallRecordService.selectTCallRecordById(id));
    }

    /**
     * 新增通话记录
     */
//    @PreAuthorize("@ss.hasPermi('business:record:add')")
//    @Log(title = "通话记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCallRecord tCallRecord)
    {
        tCallRecord.setCreateBy(getUsername());
        return toAjax(tCallRecordService.insertTCallRecord(tCallRecord));
    }

    /**
     * 修改通话记录
     */
//    @PreAuthorize("@ss.hasPermi('business:record:edit')")
//    @Log(title = "通话记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCallRecord tCallRecord)
    {
        tCallRecord.setUpdateBy(getUsername());
        return toAjax(tCallRecordService.updateTCallRecord(tCallRecord));
    }

    /**
     * 删除通话记录
     */
//    @PreAuthorize("@ss.hasPermi('business:record:remove')")
//    @Log(title = "通话记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tCallRecordService.deleteTCallRecordByIds(ids));
    }


    //2024年11月18日10:44:02  新增接口，通过sessionId返回对应的通话记录信息，并且关联曹永创的contents[当前通话记录]字段
    @GetMapping(value = "/getCallBySessionId")
    public R<TCallRecord> getCallBySessionId(String sessionId)
    {
        return R.ok(tCallRecordService.getCallBySessionId(sessionId));
    }

    /**
     * 获取客服列表接口【只返回用户的ID和姓名】
     * 2025年01月07日16:59:46 逻辑调整：因为可能用户会改名字，所以如果用户ID一样，但是姓名不一样的，就返回一条数据，名称是查询最新的用户  【机器人不用处理，因为机器人都是大模型那边固定死的】
     * @return
     */
    @GetMapping(value = "/getAgentList")
    public R<List<UserTypeResp>> getAgentList()
    {
        return R.ok(tCallRecordService.getAgentList());
    }


    /**
     * 通过通话ID，将存储的音频转换为文本，并将结果返回给前端(调用阿里云的离线接口)
     * @return
     */
    @GetMapping(value = "/updateFile2TextById")
    public R<String> updateFile2TextById(Long id)
    {
        return R.ok(tCallRecordService.updateFile2TextById(id));
    }


    /**
     * 通过通话ID，将存储的音频转换为文本，并将结果返回给前端(调用阿里云的在线接口)
     * @return
     */
    @GetMapping(value = "/updateFile2TextByIdOneLine")
    public R<String> updateFile2TextByIdOneLine(Long id)
    {
        return R.ok(tCallRecordService.updateFile2TextByIdOneLine(id));
    }

    //目录
    private static final String FILE_STORAGE_LOCATION = "/Users/wangmiaomiao/Downloads/mlvrwj.20250217/";

    /**
     * 通过通话记录的ID，下载单条通话语音
     * @param id
     * @return
     * @throws IOException
     */
    @GetMapping("/downloadById")
    public ResponseEntity<InputStreamResource> downloadFile(@RequestParam Long id) throws IOException {
        TCallRecord tCallRecord = this.tCallRecordService.selectTCallRecordById(id);
        if(Objects.isNull(tCallRecord))
            throw new ServiceException("未查询到录音");
        String url = tCallRecord.getUrl();
        if(StringUtils.isBlank(url))
            throw new ServiceException("未查询到录音");
        //查询服务器上的文件
//        url = url.replace(domain, urlDiskPrefix);
        url = fileUrlPrefix + url;
        // 构造文件的完整路径
        File file = new File(url);

        // 检查文件是否存在
        if (!file.exists()) {
            throw new RuntimeException("File not found ");
        }

        // 读取文件内容到字节数组
        byte[] fileData = Files.readAllBytes(Paths.get(file.getAbsolutePath()));

        // 设置HTTP响应头
        HttpHeaders header = new HttpHeaders();
        header.add(HttpHeaders.CONTENT_DISPOSITION, "attachment; filename=\"" + file.getName() + "\"");
        header.add(HttpHeaders.CONTENT_TYPE, MediaType.APPLICATION_OCTET_STREAM_VALUE);

        // 返回文件内容作为响应体
        return ResponseEntity.ok()
                .headers(header)
                .body(new InputStreamResource(new ByteArrayInputStream(fileData)));
    }


    /**
     * 根据筛选条件，批量下载语音
     * @param tCallRecord
     * @return
     * @throws IOException
     */
    @GetMapping("/downloadBatchByCondition")
    public ResponseEntity<Resource> downloadBatchFiles(TCallRecord tCallRecord) throws IOException {
        //2025年01月07日16:32:52 起止时间是一定要传的，否则不允许导出
        if(StringUtils.isBlank(tCallRecord.getTimeBeginReq()) || StringUtils.isBlank(tCallRecord.getTimeEndReq()))
            throw new ServiceException("批量导出数据，一定要输入起止时间！");
        //查询数据
        List<TCallRecord> tCallRecords = this.tCallRecordService.selectTCallRecordList(tCallRecord);
        if(CollectionUtils.isEmpty(tCallRecords))
            throw new ServiceException("未查询到数据");
        List<String> fileNames = new ArrayList<>(tCallRecords.size());
        for (TCallRecord callRecord : tCallRecords) {
            String url = callRecord.getUrl();
            if(StringUtils.isNotBlank(url))
//                fileNames.add(url.replace(domain, urlDiskPrefix));
                fileNames.add(fileUrlPrefix + url);
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try (ZipOutputStream zipOutputStream = new ZipOutputStream(byteArrayOutputStream)) {
            for (String fileName : fileNames) {
//                File file = new File(FILE_STORAGE_LOCATION + fileName);
                File file = new File(fileName);
                if (!file.exists()) {
                    logger.error("File not found: " + fileName);
                    continue;//查询其他的
//                    throw new RuntimeException("File not found: " + fileName);
                }
                addFileToZip(file, file.getName(), zipOutputStream);
            }
        }

        byte[] zipContent = byteArrayOutputStream.toByteArray();
        ByteArrayResource resource = new ByteArrayResource(zipContent);

        HttpHeaders headers = new HttpHeaders();
        headers.add(HttpHeaders.CONTENT_DISPOSITION, "attachment; filename=\"batch_download.zip\"");
        headers.add(HttpHeaders.CONTENT_TYPE, MediaType.APPLICATION_OCTET_STREAM_VALUE);

        return ResponseEntity.ok()
                .headers(headers)
                .contentLength(zipContent.length)
                .body(resource);
    }

    private void addFileToZip(File file, String entryName, ZipOutputStream zipOut) throws IOException {
        try (FileInputStream fis = new FileInputStream(file)) {
            ZipEntry zipEntry = new ZipEntry(entryName);
            zipOut.putNextEntry(zipEntry);

            byte[] bytes = new byte[1024];
            int length;
            while ((length = fis.read(bytes)) >= 0) {
                zipOut.write(bytes, 0, length);
            }
        }
    }
}
