package com.slibra.business.domain;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;

/**
 * 泵站对象 t_pumping_station
 * 
 * @author slibra
 * @date 2024-11-05
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class TPumpingStation extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 泵站名称 */
    @Excel(name = "泵站名称")
    private String name;

    /** 省的id */
    @Excel(name = "省的id")
    private String provinceId;

    /** 市的id */
    @Excel(name = "市的id")
    private String cityId;

    /** 区县的id */
    @Excel(name = "区县的id")
    private String countryId;

    /** 所属区（详细地址） */
    @Excel(name = "所属区", readConverterExp = "详=细地址")
    private String address;

    /** 排序（按照升序排列） */
    @Excel(name = "排序", readConverterExp = "按=照升序排列")
    private String sort;

    /** 删除标志（0代表存在 2代表删除） */
    @JsonIgnore
    private Long delFlag;

    /** 乐观锁 */
    @Excel(name = "乐观锁")
    @JsonIgnore
    private Long revision;

    //额外查询的信息
    //关联的小区  复兴小区（A#、B#、C#），康华时代（1#、2#、3#）
    private String neighbourhoodAndBuildings;

    //省的名字
    private String provinceName;

    //市的名字
    private String cityName;

    //区县的名字
    private String countryName;
}
