package com.slibra.business.service;

import java.util.HashMap;
import java.util.List;

import com.slibra.business.domain.TCallRecord;
import com.slibra.business.res.CallRecordCount;
import com.slibra.business.res.CallUserCountInfo;
import com.slibra.business.res.UserTypeResp;

/**
 * 通话记录Service接口
 * 
 * @author slibra
 * @date 2024-11-11
 */
public interface ITCallRecordService 
{
    /**
     * 查询通话记录
     * 
     * @param id 通话记录主键
     * @return 通话记录
     */
    public TCallRecord selectTCallRecordById(Long id);

    /**
     * 查询通话记录列表
     * 
     * @param tCallRecord 通话记录
     * @return 通话记录集合
     */
    public List<TCallRecord> selectTCallRecordList(TCallRecord tCallRecord);

    /**
     * 新增通话记录
     * 
     * @param tCallRecord 通话记录
     * @return 结果
     */
    public int insertTCallRecord(TCallRecord tCallRecord);

    /**
     * 修改通话记录
     * 
     * @param tCallRecord 通话记录
     * @return 结果
     */
    public int updateTCallRecord(TCallRecord tCallRecord);

    /**
     * 批量删除通话记录
     * 
     * @param ids 需要删除的通话记录主键集合
     * @return 结果
     */
    public int deleteTCallRecordByIds(Long[] ids);

    /**
     * 删除通话记录信息
     * 
     * @param id 通话记录主键
     * @return 结果
     */
    public int deleteTCallRecordById(Long id);

    TCallRecord getCallBySessionId(String sessionId);

    List<UserTypeResp> getAgentList();

    String updateFile2TextById(Long id);

    String updateFile2TextByIdOneLine(Long id);

    CallRecordCount callRecordCountInfo();

    List<CallUserCountInfo> userCallCount();

    List<CallUserCountInfo> robotCallCount();
}
