package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.CPhoneMapper;
import com.slibra.business.domain.CPhone;
import com.slibra.business.service.ICPhoneService;

/**
 * 分机信息Service业务层处理
 * 
 * @author slibra
 * @date 2024-12-02
 */
@Service
public class CPhoneServiceImpl implements ICPhoneService 
{
    @Autowired
    private CPhoneMapper cPhoneMapper;

    /**
     * 查询分机信息
     * 
     * @param id 分机信息主键
     * @return 分机信息
     */
    @Override
    public CPhone selectCPhoneById(String id)
    {
        return cPhoneMapper.selectCPhoneById(id);
    }

    /**
     * 查询分机信息列表
     * 
     * @param cPhone 分机信息
     * @return 分机信息
     */
    @Override
    public List<CPhone> selectCPhoneList(CPhone cPhone)
    {
        return cPhoneMapper.selectCPhoneList(cPhone);
    }

    /**
     * 新增分机信息
     * 
     * @param cPhone 分机信息
     * @return 结果
     */
    @Override
    public int insertCPhone(CPhone cPhone)
    {
//        cPhone.setCreateTime(DateUtils.getNowDate());
        return cPhoneMapper.insertCPhone(cPhone);
    }

    /**
     * 修改分机信息
     * 
     * @param cPhone 分机信息
     * @return 结果
     */
    @Override
    public int updateCPhone(CPhone cPhone)
    {
//        cPhone.setUpdateTime(DateUtils.getNowDate());
        return cPhoneMapper.updateCPhone(cPhone);
    }

    /**
     * 批量删除分机信息
     * 
     * @param ids 需要删除的分机信息主键
     * @return 结果
     */
    @Override
    public int deleteCPhoneByIds(String[] ids)
    {
        return cPhoneMapper.deleteCPhoneByIds(ids);
    }

    /**
     * 删除分机信息信息
     * 
     * @param id 分机信息主键
     * @return 结果
     */
    @Override
    public int deleteCPhoneById(String id)
    {
        return cPhoneMapper.deleteCPhoneById(id);
    }
}
