package com.slibra.business.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.CityMapper;
import com.slibra.business.domain.City;
import com.slibra.business.service.ICityService;

/**
 * 全国省市区数据Service业务层处理
 * 
 * @author slibra
 * @date 2024-11-11
 */
@Service
public class CityServiceImpl implements ICityService 
{
    @Autowired
    private CityMapper cityMapper;

    /**
     * 查询全国省市区数据
     * 
     * @param id 全国省市区数据主键
     * @return 全国省市区数据
     */
    @Override
    public City selectCityById(String id)
    {
        return cityMapper.selectCityById(id);
    }

    /**
     * 查询全国省市区数据列表
     * 
     * @param city 全国省市区数据
     * @return 全国省市区数据
     */
    @Override
    public List<City> selectCityList(City city)
    {
        return cityMapper.selectCityList(city);
    }

    /**
     * 新增全国省市区数据
     * 
     * @param city 全国省市区数据
     * @return 结果
     */
    @Override
    public int insertCity(City city)
    {
        return cityMapper.insertCity(city);
    }

    /**
     * 修改全国省市区数据
     * 
     * @param city 全国省市区数据
     * @return 结果
     */
    @Override
    public int updateCity(City city)
    {
        return cityMapper.updateCity(city);
    }

    /**
     * 批量删除全国省市区数据
     * 
     * @param ids 需要删除的全国省市区数据主键
     * @return 结果
     */
    @Override
    public int deleteCityByIds(String[] ids)
    {
        return cityMapper.deleteCityByIds(ids);
    }

    /**
     * 删除全国省市区数据信息
     * 
     * @param id 全国省市区数据主键
     * @return 结果
     */
    @Override
    public int deleteCityById(String id)
    {
        return cityMapper.deleteCityById(id);
    }
}
