package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TUserInfoMapper;
import com.slibra.business.domain.TUserInfo;
import com.slibra.business.service.ITUserInfoService;

/**
 * 用户信息Service业务层处理
 * 
 * @author slibra
 * @date 2024-11-06
 */
@Service
public class TUserInfoServiceImpl implements ITUserInfoService 
{
    @Autowired
    private TUserInfoMapper tUserInfoMapper;

    /**
     * 查询用户信息
     * 
     * @param id 用户信息主键
     * @return 用户信息
     */
    @Override
    public TUserInfo selectTUserInfoById(Long id)
    {
        return tUserInfoMapper.selectTUserInfoById(id);
    }

    /**
     * 查询用户信息列表
     * 
     * @param tUserInfo 用户信息
     * @return 用户信息
     */
    @Override
    public List<TUserInfo> selectTUserInfoList(TUserInfo tUserInfo)
    {
        return tUserInfoMapper.selectTUserInfoList(tUserInfo);
    }

    /**
     * 新增用户信息
     * 
     * @param tUserInfo 用户信息
     * @return 结果
     */
    @Override
    public int insertTUserInfo(TUserInfo tUserInfo)
    {
        tUserInfo.setCreateTime(DateUtils.getNowDate());
        return tUserInfoMapper.insertTUserInfo(tUserInfo);
    }

    /**
     * 修改用户信息
     * 
     * @param tUserInfo 用户信息
     * @return 结果
     */
    @Override
    public int updateTUserInfo(TUserInfo tUserInfo)
    {
        tUserInfo.setUpdateTime(DateUtils.getNowDate());
        return tUserInfoMapper.updateTUserInfo(tUserInfo);
    }

    /**
     * 批量删除用户信息
     * 
     * @param ids 需要删除的用户信息主键
     * @return 结果
     */
    @Override
    public int deleteTUserInfoByIds(Long[] ids)
    {
        return tUserInfoMapper.deleteTUserInfoByIds(ids);
    }

    /**
     * 删除用户信息信息
     * 
     * @param id 用户信息主键
     * @return 结果
     */
    @Override
    public int deleteTUserInfoById(Long id)
    {
        return tUserInfoMapper.deleteTUserInfoById(id);
    }
}
