package com.slibra.business.service.impl;

import java.util.List;
import com.slibra.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.slibra.business.mapper.TZuoxiRecordMapper;
import com.slibra.business.domain.TZuoxiRecord;
import com.slibra.business.service.ITZuoxiRecordService;

/**
 * 添加坐席用户记录Service业务层处理
 * 
 * @author slibra
 * @date 2025-01-08
 */
@Service
public class TZuoxiRecordServiceImpl implements ITZuoxiRecordService 
{
    @Autowired
    private TZuoxiRecordMapper tZuoxiRecordMapper;

    /**
     * 查询添加坐席用户记录
     * 
     * @param id 添加坐席用户记录主键
     * @return 添加坐席用户记录
     */
    @Override
    public TZuoxiRecord selectTZuoxiRecordById(Long id)
    {
        return tZuoxiRecordMapper.selectTZuoxiRecordById(id);
    }

    /**
     * 查询添加坐席用户记录列表
     * 
     * @param tZuoxiRecord 添加坐席用户记录
     * @return 添加坐席用户记录
     */
    @Override
    public List<TZuoxiRecord> selectTZuoxiRecordList(TZuoxiRecord tZuoxiRecord)
    {
        return tZuoxiRecordMapper.selectTZuoxiRecordList(tZuoxiRecord);
    }

    /**
     * 新增添加坐席用户记录
     * 
     * @param tZuoxiRecord 添加坐席用户记录
     * @return 结果
     */
    @Override
    public int insertTZuoxiRecord(TZuoxiRecord tZuoxiRecord)
    {
        tZuoxiRecord.setCreateTime(DateUtils.getNowDate());
        return tZuoxiRecordMapper.insertTZuoxiRecord(tZuoxiRecord);
    }

    /**
     * 修改添加坐席用户记录
     * 
     * @param tZuoxiRecord 添加坐席用户记录
     * @return 结果
     */
    @Override
    public int updateTZuoxiRecord(TZuoxiRecord tZuoxiRecord)
    {
        tZuoxiRecord.setUpdateTime(DateUtils.getNowDate());
        return tZuoxiRecordMapper.updateTZuoxiRecord(tZuoxiRecord);
    }

    /**
     * 批量删除添加坐席用户记录
     * 
     * @param ids 需要删除的添加坐席用户记录主键
     * @return 结果
     */
    @Override
    public int deleteTZuoxiRecordByIds(Long[] ids)
    {
        return tZuoxiRecordMapper.deleteTZuoxiRecordByIds(ids);
    }

    /**
     * 删除添加坐席用户记录信息
     * 
     * @param id 添加坐席用户记录主键
     * @return 结果
     */
    @Override
    public int deleteTZuoxiRecordById(Long id)
    {
        return tZuoxiRecordMapper.deleteTZuoxiRecordById(id);
    }
}
